import os
from bkg_estimator import *

def unit_test(pha='test.pha', obsid=1200040103,root='testdata',
              kpfile = "https://heasarc.gsfc.nasa.gov/FTP/caldb/data/gen/pcf/geomag/kp_potsdam.fits",
              numfpms = 52,
              bevt="https://heasarc.gsfc.nasa.gov/FTP/caldb/data/nicer/xti/pcf/30nov18targskc_enhanced.evt"):
    """
    The unit test will run a sample background calculation.  It assumes the data are located in a subdirectory called "testdata"
    of the current working directory
    :param pha: the name of the pha file
    :param obsid: the test nicer observation id for the dataset
    :param root: the path to the testdata directory
    :param kpfile: The file containing the space-weather KP parameters
    :param bevt: the events file created from the NICER background (blank-sky) observations.
    :return:
    """
    srcpha = os.path.join(root,pha)
    # create mkf3 file from mkf2 file
    mkf2  = os.path.join(root,str(obsid),'auxil','ni1200040103.mkf2')
    mkf3 = mkf2.replace('.mkf2','.mkf3')
    print('Making mkf3 file {0}'.format(mkf3))
    s = add_kp(mkf2, clobber=True, kpfile=kpfile)
    #bkg_chan, bkgspec_tot, bexpotot = mk_bkg_spec_evt(srcpha, gti=gtip, mkffile=mkf3, gtimin=0.1)
    print('Making Background Spectrum')
    bkg_chan, bkgspec_tot, bexpotot = mk_bkg_spec_evt(srcpha, mkf3, bevt=bevt, numfpms = numfpms, gtimin=0, gti=None, clobber=True, verbose=False)
    return bkg_chan, bkgspec_tot, bexpotot

if __name__ == '__main__':
    unit_test()
